@@ -33,37 +33,37 @@ test_that("functions returns a list", {
   expect_type(pwgd(1,alpha=.1,lambda=1), "double")
   expect_type(qwgd(.1,alpha=.1,lambda=1), "double")
   expect_type(rwgd(1,alpha=.1,lambda=1), "double")
-  expect_type(ddld(1,theta=1), "double")
-  expect_type(pdld(1,theta=1), "double")
-  expect_type(qdld(.1,theta=1), "double")
-  expect_type(rdld(1,theta=1), "double")
-  expect_type(ddld(1,theta=1), "double")
-  expect_type(pdld(1,theta=1), "double")
-  expect_type(qdld(.1,theta=1), "double")
-  expect_type(rdld(1,theta=1), "double")
-  expect_type(depkd(1,lambda=1,alpha=1), "double")
-  expect_type(pepkd(1,lambda=1,alpha=1), "double")
-  expect_type(qepkd(.1,lambda=1,alpha=1), "double")
-  expect_type(repkd(1,lambda=1,alpha=1), "double")
+  expect_type(ddLd1(1,theta=1), "double")
+  expect_type(pdLd1(1,theta=1), "double")
+  expect_type(qdLd1(.1,theta=1), "double")
+  expect_type(rdLd1(1,theta=1), "double")
+  expect_type(ddLd1(1,theta=1), "double")
+  expect_type(pdLd1(1,theta=1), "double")
+  expect_type(qdLd1(.1,theta=1), "double")
+  expect_type(rdLd1(1,theta=1), "double")
+  expect_type(dkd(1,lambda=1,alpha=1), "double")
+  expect_type(pkd(1,lambda=1,alpha=1), "double")
+  expect_type(qkd(.1,lambda=1,alpha=1), "double")
+  expect_type(rkd(1,lambda=1,alpha=1), "double")
   expect_type(dgld(1, a=1, alpha=1, beta=1), "double")
   expect_type(pgld(1, a=1, alpha=1, beta=1), "double")
   expect_type(qgld(.1, a=2, alpha=1, beta=1), "double")
   expect_type(rgld(1, a=1, alpha=1, beta=1), "double")
-  expect_type(dndd(1, theta=1), "double")
-  expect_type(dndd(-1, theta=1), "double")
-  expect_type(dndd(-1, theta=1,log=T), "double")
-  expect_type(pndd(1, theta=1), "double")
-  expect_type(pndd(-1, theta=1), "double")
-  expect_type(qndd(.1, theta=1), "double")
-  expect_type(rndd(1, theta=1), "double")
+  expect_type(dLd(1, theta=1), "double")
+  expect_type(dLd(-1, theta=1), "double")
+  expect_type(dLd(-1, theta=1,log=T), "double")
+  expect_type(pLd(1, theta=1), "double")
+  expect_type(pLd(-1, theta=1), "double")
+  expect_type(qLd(.1, theta=1), "double")
+  expect_type(rLd(1, theta=1), "double")
   expect_type(dEPd(1, lambda=1,beta=1), "double")
   expect_type(pEPd(1, lambda=1,beta=1), "double")
   expect_type(qEPd(.1, lambda=1,beta=1), "double")
   expect_type(rEPd(1, lambda=1,beta=1), "double")
-  expect_type(dnoPDD(1, theta=1), "double")
-  expect_type(pnoPDD(1, theta=1), "double")
-  expect_type(qnoPDD(.1, theta=1), "double")
-  expect_type(rnoPDD(1, theta=1), "double")
+  expect_type(dRA(1, theta=1), "double")
+  expect_type(pRA(1, theta=1), "double")
+  expect_type(qRA(.1, theta=1), "double")
+  expect_type(rRA(1, theta=1), "double")
   expect_type(domd(1, alpha=.1), "double")
   expect_type(pomd(1, alpha=.1), "double")
   expect_type(qomd(.1, alpha=.1), "double")
@@ -72,10 +72,11 @@ test_that("functions returns a list", {
   expect_type(ppldd(1, alpha=1, beta=1, theta=1), "double")
   expect_type(qpldd(.1, alpha=1, beta=1, theta=1), "double")
   expect_type(rpldd(1, alpha=1, beta=1, theta=1), "double")
-  expect_type(drld(1, theta=1), "double")
-  expect_type(prld(1, theta=1), "double")
-  expect_type(qrld(.1, theta=1), "double")
-  expect_type(rrld(1, theta=1), "double")
+  expect_type(ddLd2(1, theta=1), "double")
+  expect_type(pdLd2(1, theta=1), "double")
+  expect_type(pdLd2(-1, theta=1), "double")
+  expect_type(qdLd2(.1, theta=1), "double")
+  expect_type(rdLd2(1, theta=1), "double")
 })
 # ## Test whether the code throw an error.
 test_that("functions returns errors", {
@@ -159,28 +160,28 @@ the first and second moment does not exist!")
   expect_error(rwgd(-1,alpha=2,lambda=3), "n must be >= 1")
   expect_error(rwgd(1,alpha=2,lambda=3), "alpha must be between >= 0 and <= 1")
   expect_error(rwgd(1, alpha=.2, lambda=-3), "lambda must be > 0")
-  expect_error(ddld(1, theta = -1), "theta must be > 0")
-  expect_error(pdld(1, theta = -1), "theta must be > 0")
-  expect_error(qdld(10, theta = 1), "p must be between >= 0 and <= 1")
-  expect_error(qdld(.1, theta = -1), "theta must be > 0")
-  expect_error(rdld(-1, theta = 1), "n must be >= 1")
-  expect_error(rdld(10, theta = -1), "theta must be > 0")
-  expect_error(demd(1, theta = -1), "theta must be > 0")
-  expect_error(pemd(1, theta = -1), "theta must be > 0")
-  expect_error(qemd(10, theta = 1), "p must be between >= 0 and <= 1")
-  expect_error(qemd(.1, theta = -1), "theta must be > 0")
-  expect_error(remd(-1, theta = 1), "n must be >= 1")
-  expect_error(remd(10, theta = -1), "theta must be > 0")
-  expect_error(depkd(0.1, lambda=-2, alpha=3), "lambda must be > 0")
-  expect_error(depkd(0.1, lambda=2, alpha=-3), "alpha must be > 0")
-  expect_error(pepkd(0.1, lambda=-2, alpha=3), "lambda must be > 0")
-  expect_error(pepkd(0.1, lambda=2, alpha=-3), "alpha must be > 0")
-  expect_error(qepkd(-0.1,lambda=2,alpha=3), "p must be between >= 0 and <= 1")
-  expect_error(qepkd(0.1, lambda=-2, alpha=3), "lambda must be > 0")
-  expect_error(qepkd(0.1, lambda=2, alpha=-3), "alpha must be > 0")
-  expect_error(repkd(0.1, lambda=2, alpha=3), "n must be >= 1")
-  expect_error(repkd(10, lambda=-2, alpha=3), "lambda must be > 0")
-  expect_error(repkd(10, lambda=2, alpha=-3), "alpha must be > 0")
+  expect_error(ddLd1(1, theta = -1), "theta must be > 0")
+  expect_error(pdLd1(1, theta = -1), "theta must be > 0")
+  expect_error(qdLd1(10, theta = 1), "p must be between >= 0 and <= 1")
+  expect_error(qdLd1(.1, theta = -1), "theta must be > 0")
+  expect_error(rdLd1(-1, theta = 1), "n must be >= 1")
+  expect_error(rdLd1(10, theta = -1), "theta must be > 0")
+  expect_error(dmd(1, theta = -1), "theta must be > 0")
+  expect_error(pmd(1, theta = -1), "theta must be > 0")
+  expect_error(qmd(10, theta = 1), "p must be between >= 0 and <= 1")
+  expect_error(qmd(.1, theta = -1), "theta must be > 0")
+  expect_error(rmd(-1, theta = 1), "n must be >= 1")
+  expect_error(rmd(10, theta = -1), "theta must be > 0")
+  expect_error(dkd(0.1, lambda=-2, alpha=3), "lambda must be > 0")
+  expect_error(dkd(0.1, lambda=2, alpha=-3), "alpha must be > 0")
+  expect_error(pkd(0.1, lambda=-2, alpha=3), "lambda must be > 0")
+  expect_error(pkd(0.1, lambda=2, alpha=-3), "alpha must be > 0")
+  expect_error(qkd(-0.1,lambda=2,alpha=3), "p must be between >= 0 and <= 1")
+  expect_error(qkd(0.1, lambda=-2, alpha=3), "lambda must be > 0")
+  expect_error(qkd(0.1, lambda=2, alpha=-3), "alpha must be > 0")
+  expect_error(rkd(0.1, lambda=2, alpha=3), "n must be >= 1")
+  expect_error(rkd(10, lambda=-2, alpha=3), "lambda must be > 0")
+  expect_error(rkd(10, lambda=2, alpha=-3), "alpha must be > 0")
   expect_error(dgld(1, a=-2, alpha=3, beta=4), "a must be > 0")
   expect_error(dgld(1, a=2, alpha=-3, beta=4), "alpha must be > 0")
   expect_error(dgld(1, a=2, alpha=3, beta=-4), "beta must be > 0")
@@ -195,12 +196,12 @@ the first and second moment does not exist!")
   expect_error(rgld(10, a=-2, alpha=3, beta=4), "a must be > 0")
   expect_error(rgld(10, a=2, alpha=-3, beta=4), "alpha must be > 0")
   expect_error(rgld(10, a=2, alpha=3, beta=-4), "beta must be > 0")
-  expect_error(dndd(1, theta = -1), "theta must be > 0")
-  expect_error(pndd(1, theta = -1), "theta must be > 0")
-  expect_error(qndd(10, theta = 1), "p must be between >= 0 and <= 1")
-  expect_error(qndd(.1, theta = -1), "theta must be > 0")
-  expect_error(rndd(-1, theta = 1), "n must be >= 1")
-  expect_error(rndd(10, theta = -1), "theta must be > 0")
+  expect_error(dLd(1, theta = -1), "theta must be > 0")
+  expect_error(pLd(1, theta = -1), "theta must be > 0")
+  expect_error(qLd(10, theta = 1), "p must be between >= 0 and <= 1")
+  expect_error(qLd(.1, theta = -1), "theta must be > 0")
+  expect_error(rLd(-1, theta = 1), "n must be >= 1")
+  expect_error(rLd(10, theta = -1), "theta must be > 0")
   expect_error(dEPd(1, lambda=-2, beta=3), "lambda must be > 0")
   expect_error(dEPd(1, lambda=2, beta=-3), "beta must be > 0")
   expect_error(pEPd(1, lambda=-2, beta=3), "lambda must be > 0")
@@ -211,12 +212,12 @@ the first and second moment does not exist!")
   expect_error(rEPd(-1, lambda=2, beta=3), "n must be >= 1")
   expect_error(rEPd(1, lambda=-2, beta=3), "lambda must be > 0")
   expect_error(rEPd(1, lambda=2, beta=-3), "beta must be > 0")
-  expect_error(dnoPDD(1, theta = -1), "theta must be > 0")
-  expect_error(pnoPDD(1, theta = -1), "theta must be > 0")
-  expect_error(qnoPDD(10, theta = 1), "p must be between >= 0 and <= 1")
-  expect_error(qnoPDD(.1, theta = -1), "theta must be > 0")
-  expect_error(rnoPDD(-1, theta = 1), "n must be >= 1")
-  expect_error(rnoPDD(10, theta = -1), "theta must be > 0")
+  expect_error(dRA(1, theta = -1), "theta must be > 0")
+  expect_error(pRA(1, theta = -1), "theta must be > 0")
+  expect_error(qRA(10, theta = 1), "p must be between >= 0 and <= 1")
+  expect_error(qRA(.1, theta = -1), "theta must be > 0")
+  expect_error(rRA(-1, theta = 1), "n must be >= 1")
+  expect_error(rRA(10, theta = -1), "theta must be > 0")
   expect_error(domd(1, alpha=-0.2), "alpha must be > 0 and <= 1")
   expect_error(pomd(1, alpha=-0.2), "alpha must be > 0 and <= 1")
   expect_error(qomd(2, alpha=0.2), "p must be between >= 0 and <= 1")
@@ -233,12 +234,12 @@ the first and second moment does not exist!")
   expect_error(rpldd(-1, alpha=-2, beta=3, theta=4), "n must be >= 1")
   expect_error(rpldd(10, alpha=-2, beta=3, theta=4), "alpha must be > 0")
   expect_error(rpldd(10, alpha=2, beta=3, theta=-4), "theta must be >= 0")
-  expect_error(drld(1, theta = -1), "theta must be > 0")
-  expect_error(prld(1, theta = -1), "theta must be > 0")
-  expect_error(qrld(10, theta = 1), "p must be between >= 0 and <= 1")
-  expect_error(qrld(.1, theta = -1), "theta must be > 0")
-  expect_error(rrld(-1, theta = 1), "n must be >= 1")
-  expect_error(rrld(10, theta = -1), "theta must be > 0")
+  expect_error(ddLd2(1, theta = -1), "theta must be > 0")
+  expect_error(pdLd2(1, theta = -1), "theta must be > 0")
+  expect_error(qdLd2(10, theta = 1), "p must be between >= 0 and <= 1")
+  expect_error(qdLd2(.1, theta = -1), "theta must be > 0")
+  expect_error(rdLd2(-1, theta = 1), "n must be >= 1")
+  expect_error(rdLd2(10, theta = -1), "theta must be > 0")
 })
 # ## Test whether the output is a vector with the expected size
 test_that("functions returns a  vector with the expected size", {
@@ -342,39 +343,39 @@ test_that("functions returns a  vector with the expected size", {
   expect_vector(qwgd(.1, alpha=.2, lambda=3, lower.tail = F),
                 ptype = double(), size = 1)
   expect_vector(rwgd(20, alpha=.2, lambda=3), ptype = double(), size = 20)
-  expect_vector(ddld(1, theta=0.5), ptype = double(), size = 1)
-  expect_vector(ddld(-1, theta=0.5), ptype = double(), size = 1)
-  expect_vector(ddld(1, theta=0.5,log=T), ptype = double(), size = 1)
-  expect_vector(pdld(1, theta=0.5), ptype = double(), size = 1)
-  expect_vector(pdld(-1, theta=0.5), ptype = double(), size = 1)
-  expect_vector(pdld(1, theta=0.5, lower.tail = F), ptype = double(), size = 1)
-  expect_vector(pdld(1, theta=0.5, log.p = T), ptype = double(), size = 1)
-  expect_vector(qdld(.1, theta=0.5), ptype = double(), size = 1)
-  expect_vector(qdld(0.1, theta=0.5, lower.tail = F),
+  expect_vector(ddLd1(1, theta=0.5), ptype = double(), size = 1)
+  expect_vector(ddLd1(-1, theta=0.5), ptype = double(), size = 1)
+  expect_vector(ddLd1(1, theta=0.5,log=T), ptype = double(), size = 1)
+  expect_vector(pdLd1(1, theta=0.5), ptype = double(), size = 1)
+  expect_vector(pdLd1(-1, theta=0.5), ptype = double(), size = 1)
+  expect_vector(pdLd1(1, theta=0.5, lower.tail = F), ptype = double(), size = 1)
+  expect_vector(pdLd1(1, theta=0.5, log.p = T), ptype = double(), size = 1)
+  expect_vector(qdLd1(.1, theta=0.5), ptype = double(), size = 1)
+  expect_vector(qdLd1(0.1, theta=0.5, lower.tail = F),
                 ptype = double(), size = 1)
-  expect_vector(rdld(20, theta=0.5), ptype = double(), size = 20)
-  expect_vector(demd(1, theta=0.5), ptype = double(), size = 1)
-  expect_vector(demd(-1, theta=0.5), ptype = double(), size = 1)
-  expect_vector(demd(1, theta=0.5, log=T), ptype = double(), size = 1)
-  expect_vector(pemd(1, theta=0.5), ptype = double(), size = 1)
-  expect_vector(pemd(-1, theta=0.5), ptype = double(), size = 1)
-  expect_vector(pemd(1, theta=0.5, lower.tail = F), ptype = double(), size = 1)
-  expect_vector(pemd(1, theta=0.5, log.p = T), ptype = double(), size = 1)
-  expect_vector(qemd(.1, theta=0.5), ptype = double(), size = 1)
-  expect_vector(qemd(.1, theta=0.5, lower.tail = F), ptype = double(), size = 1)
-  expect_vector(remd(20, theta=0.5), ptype = double(), size = 20)
-  expect_vector(depkd(0.1, lambda=2, alpha=3), ptype = double(), size = 1)
-  expect_vector(depkd(0.1, lambda=2, alpha=3, log = T),
+  expect_vector(rdLd1(20, theta=0.5), ptype = double(), size = 20)
+  expect_vector(dmd(1, theta=0.5), ptype = double(), size = 1)
+  expect_vector(dmd(-1, theta=0.5), ptype = double(), size = 1)
+  expect_vector(dmd(1, theta=0.5, log=T), ptype = double(), size = 1)
+  expect_vector(pmd(1, theta=0.5), ptype = double(), size = 1)
+  expect_vector(pmd(-1, theta=0.5), ptype = double(), size = 1)
+  expect_vector(pmd(1, theta=0.5, lower.tail = F), ptype = double(), size = 1)
+  expect_vector(pmd(1, theta=0.5, log.p = T), ptype = double(), size = 1)
+  expect_vector(qmd(.1, theta=0.5), ptype = double(), size = 1)
+  expect_vector(qmd(.1, theta=0.5, lower.tail = F), ptype = double(), size = 1)
+  expect_vector(rmd(20, theta=0.5), ptype = double(), size = 20)
+  expect_vector(dkd(0.1, lambda=2, alpha=3), ptype = double(), size = 1)
+  expect_vector(dkd(0.1, lambda=2, alpha=3, log = T),
                 ptype = double(), size = 1)
-  expect_vector(pepkd(0.1, lambda=2, alpha=3), ptype = double(), size = 1)
-  expect_vector(pepkd(0.1, lambda=2, alpha=3, log.p = T),
+  expect_vector(pkd(0.1, lambda=2, alpha=3), ptype = double(), size = 1)
+  expect_vector(pkd(0.1, lambda=2, alpha=3, log.p = T),
                 ptype = double(), size = 1)
-  expect_vector(pepkd(0.1, lambda=2, alpha=3, lower.tail = F),
+  expect_vector(pkd(0.1, lambda=2, alpha=3, lower.tail = F),
                 ptype = double(), size = 1)
-  expect_vector(qepkd(0.1, lambda=2, alpha=3), ptype = double(), size = 1)
-  expect_vector(qepkd(0.1, lambda=2, alpha=3, lower.tail = F),
+  expect_vector(qkd(0.1, lambda=2, alpha=3), ptype = double(), size = 1)
+  expect_vector(qkd(0.1, lambda=2, alpha=3, lower.tail = F),
                 ptype = double(), size = 1)
-  expect_vector(repkd(20, lambda=2,alpha=3), ptype = double(), size = 20)
+  expect_vector(rkd(20, lambda=2,alpha=3), ptype = double(), size = 20)
   expect_vector(dgld(1, a=2, alpha=3, beta=4), ptype = double(), size = 1)
   expect_vector(dgld(-1, a=2, alpha=3, beta=4), ptype = double(), size = 1)
   expect_vector(dgld(1, a=2, alpha=3, beta=4, log = T),
@@ -391,15 +392,15 @@ test_that("functions returns a  vector with the expected size", {
   expect_vector(qgld(.1, a=2, alpha=3, beta=4, lower.tail = T),
                 ptype = double(), size = 1)
   expect_vector(rgld(20, a=2, alpha=3, beta=4), ptype = double(), size = 20)
-  expect_vector(dndd(.5,theta=2), ptype = double(), size = 1)
-  expect_vector(pndd(.5,theta=2), ptype = double(), size = 1)
-  expect_vector(pndd(.5,theta=2,lower.tail=F), ptype = double(), size = 1)
-  expect_vector(pndd(.5,theta=2,log.p=T), ptype = double(), size = 1)
-  expect_vector(pndd(-5,theta=2,log.p=F), ptype = double(), size = 1)
-  expect_vector(qndd(.5,theta=2), ptype = double(), size = 1)
-  expect_vector(qndd(c(.5,.2),theta=c(2,3),lower.tail=F),
+  expect_vector(dLd(.5,theta=2), ptype = double(), size = 1)
+  expect_vector(pLd(.5,theta=2), ptype = double(), size = 1)
+  expect_vector(pLd(.5,theta=2,lower.tail=F), ptype = double(), size = 1)
+  expect_vector(pLd(.5,theta=2,log.p=T), ptype = double(), size = 1)
+  expect_vector(pLd(-5,theta=2,log.p=F), ptype = double(), size = 1)
+  expect_vector(qLd(.5,theta=2), ptype = double(), size = 1)
+  expect_vector(qLd(c(.5,.2),theta=c(2,3),lower.tail=F),
                 ptype = double(), size = 2)
-  expect_vector(rndd(20,theta=2), ptype = double(), size = 20)
+  expect_vector(rLd(20,theta=2), ptype = double(), size = 20)
   expect_vector(dEPd(1, lambda=2, beta=3), ptype = double(), size = 1)
   expect_vector(dEPd(-1, lambda=2, beta=3), ptype = double(), size = 1)
   expect_vector(dEPd(1, lambda=2, beta=3, log = T), ptype = double(), size = 1)
@@ -413,16 +414,16 @@ test_that("functions returns a  vector with the expected size", {
   expect_vector(qEPd(.1, lambda=2, beta=3, lower.tail = F),
                 ptype = double(), size = 1)
   expect_vector(rEPd(20, lambda=2, beta=3), ptype = double(), size = 20)
-  expect_vector(dnoPDD(1,theta=2), ptype = double(), size = 1)
-  expect_vector(dnoPDD(-1,theta=2), ptype = double(), size = 1)
-  expect_vector(dnoPDD(1, theta=2, log = T), ptype = double(), size = 1)
-  expect_vector(pnoPDD(1, theta=2), ptype = double(), size = 1)
-  expect_vector(pnoPDD(1, theta=2, lower.tail = F), ptype = double(), size = 1)
-  expect_vector(pnoPDD(1, theta=2, log.p = T), ptype = double(), size = 1)
-  expect_vector(pnoPDD(-1, theta=2, log.p = T), ptype = double(), size = 1)
-  expect_vector(qnoPDD(.1, theta=2), ptype = double(), size = 1)
-  expect_vector(qnoPDD(.1, theta=2, lower.tail = F), ptype = double(), size = 1)
-  expect_vector(rnoPDD(20,theta=2), ptype = double(), size = 20)
+  expect_vector(dRA(1,theta=2), ptype = double(), size = 1)
+  expect_vector(dRA(-1,theta=2), ptype = double(), size = 1)
+  expect_vector(dRA(1, theta=2, log = T), ptype = double(), size = 1)
+  expect_vector(pRA(1, theta=2), ptype = double(), size = 1)
+  expect_vector(pRA(1, theta=2, lower.tail = F), ptype = double(), size = 1)
+  expect_vector(pRA(1, theta=2, log.p = T), ptype = double(), size = 1)
+  expect_vector(pRA(-1, theta=2, log.p = T), ptype = double(), size = 1)
+  expect_vector(qRA(.1, theta=2), ptype = double(), size = 1)
+  expect_vector(qRA(.1, theta=2, lower.tail = F), ptype = double(), size = 1)
+  expect_vector(rRA(20,theta=2), ptype = double(), size = 20)
   expect_vector(domd(.8, alpha=.1), ptype = double(), size = 1)
   expect_vector(domd(-.8, alpha=.1), ptype = double(), size = 1)
   expect_vector(domd(.8, alpha=.1, log = T), ptype = double(), size = 1)
@@ -446,14 +447,50 @@ test_that("functions returns a  vector with the expected size", {
                 ptype = double(), size = 1)
   expect_vector(rpldd(20, alpha=2, beta=3, theta=4), ptype = double(),
                 size = 20)
-  expect_vector(drld(1, theta=5), ptype = double(), size = 1)
-  expect_vector(drld(-1, theta=5), ptype = double(), size = 1)
-  expect_vector(drld(1, theta=5, log=T), ptype = double(), size = 1)
-  expect_vector(prld(1, theta=5), ptype = double(), size = 1)
-  expect_vector(prld(-1, theta=5), ptype = double(), size = 1)
-  expect_vector(prld(1, theta=5, log.p = T), ptype = double(), size = 1)
-  expect_vector(prld(1, theta=5, lower.tail = F), ptype = double(), size = 1)
-  expect_vector(qrld(.1, theta=5), ptype = double(), size = 1)
-  expect_vector(qrld(.1, theta=5, lower.tail = F), ptype = double(), size = 1)
-  expect_vector(rrld(20, theta=5), ptype = double(), size = 20)
+  expect_vector(ddLd2(-1, theta=5), ptype = double(), size = 1)
+  expect_vector(ddLd2(-1, theta=5), ptype = double(), size = 1)
+  expect_vector(ddLd2(1, theta=5, log=T), ptype = double(), size = 1)
+  expect_vector(pdLd2(1, theta=5), ptype = double(), size = 1)
+  expect_vector(pdLd2(-1, theta=5), ptype = double(), size = 1)
+  expect_vector(pdLd2(-1, theta=5, log.p = T), ptype = double(), size = 1)
+  expect_vector(pdLd2(-1, theta=5, log.p = F), ptype = double(), size = 1)
+  expect_vector(pdLd2(-1, theta=5, log.p = T, lower.tail = F),
+                ptype = double(), size = 1)
+  expect_vector(pdLd2(-1, theta=5, log.p = F, lower.tail = T),
+                ptype = double(), size = 1)
+  expect_vector(pdLd2(-1, theta=5, log.p = F, lower.tail = F),
+                ptype = double(), size = 1)
+  expect_vector(pdLd2(-1, theta=5, log.p = T, lower.tail = T),
+                ptype = double(), size = 1)
+  expect_vector(pdLd2(-1, theta=5, lower.tail = F), ptype = double(), size = 1)
+  expect_vector(pdLd2(-1, theta=5, log.p = T), ptype = double(), size = 1)
+  expect_vector(pdLd2(-1, theta=5, lower.tail = F), ptype = double(), size = 1)
+  expect_vector(pdLd2(-1, theta=5, lower.tail = T), ptype = double(), size = 1)
+  expect_vector(pdLd2(1, theta=5), ptype = double(), size = 1)
+  expect_vector(pdLd2(1, theta=5), ptype = double(), size = 1)
+  expect_vector(pdLd2(1, theta=5, log.p = T), ptype = double(), size = 1)
+  expect_vector(pdLd2(1, theta=5, log.p = F), ptype = double(), size = 1)
+  expect_vector(pdLd2(1, theta=5, log.p = T, lower.tail = F),
+                ptype = double(), size = 1)
+  expect_vector(pdLd2(1, theta=5, log.p = F, lower.tail = T),
+                ptype = double(), size = 1)
+  expect_vector(pdLd2(1, theta=5, log.p = F, lower.tail = F),
+                ptype = double(), size = 1)
+  expect_vector(pdLd2(1, theta=5, log.p = T, lower.tail = T),
+                ptype = double(), size = 1)
+  expect_vector(pdLd2(1, theta=5, lower.tail = F), ptype = double(), size = 1)
+  expect_vector(pdLd2(1, theta=5, log.p = T), ptype = double(), size = 1)
+  expect_vector(pdLd2(1, theta=5, lower.tail = F), ptype = double(), size = 1)
+  expect_vector(pdLd2(1, theta=5, lower.tail = T), ptype = double(), size = 1)
+  expect_vector(pdLd2(0, theta=5, lower.tail = F), ptype = double(), size = 1)
+  expect_vector(pdLd2(0, theta=5, log.p = T), ptype = double(), size = 1)
+  expect_vector(pdLd2(0, theta=5, lower.tail = F), ptype = double(), size = 1)
+  expect_vector(pdLd2(0, theta=5, lower.tail = T), ptype = double(), size = 1)
+  expect_vector(pdLd2(.5,theta=2), ptype = double(), size = 1)
+  expect_vector(pdLd2(.5,theta=2,lower.tail=F), ptype = double(), size = 1)
+  expect_vector(pdLd2(.5,theta=2,log.p=T), ptype = double(), size = 1)
+  expect_vector(pdLd2(-5,theta=2,log.p=F), ptype = double(), size = 1)
+  expect_vector(qdLd2(.1, theta=5), ptype = double(), size = 1)
+  expect_vector(qdLd2(.1, theta=5, lower.tail = F), ptype = double(), size = 1)
+  expect_vector(rdLd2(20, theta=5), ptype = double(), size = 20)
 })
